scxpand.util.general\_util
==========================

.. automodule:: scxpand.util.general_util

   
   .. rubric:: Functions

   .. autosummary::
   
      compute_error_rate
      compute_false_negative_rate
      compute_false_positive_rate
      compute_row_sums
      compute_scaling_factors
      convert_enums_to_values
      copy_array_like
      decisions_to_probabilities
      ensure_numpy_array
      flatten_dict
      flatten_nested_dict
      floats_to_str
      format_float
      get_device
      get_elapsed_time_str
      get_last_git_commit_link
      get_local_time
      get_new_version_path
      get_utc_time
      load_and_override_params
      load_params
      log_inference_progress
      log_nested_metrics
      metrics_dict_to_dataframes
      metrics_dict_to_table
      nested_dict_to_flat_str
      nested_dict_to_multiline_str
      num2str
      save_json_data
      save_params
      set_seed
      sigmoid
      time_seconds_to_str
      time_to_str
      to_np
   